@@ -205,14 +205,9 @@ type MachineConfig struct {
 	Guest     *MachineGuest           `json:"guest,omitempty"`
 	Metrics   *MachineMetrics         `json:"metrics"`
 	Schedule  string                  `json:"schedule,omitempty"`
-	Network   *MachineNetwork         `json:"network,omitempty"`
 	Checks    map[string]MachineCheck `json:"checks,omitempty"`
 }
 
-type MachineNetwork struct {
-	ID int `json:"id"`
-}
-
 type MachineLease struct {
 	Status string `json:"status"`
 	Data   struct {
