@@ -59,6 +59,8 @@ type Query struct {
 	TemplateDeploymentNode *TemplateDeployment
 	ReleaseCommandNode     *ReleaseCommand
 
+	ValidateConfig AppConfig
+
 	// hack to let us alias node to a type
 	// DNSZone *DNSZone
 
@@ -281,14 +283,16 @@ func (img *ImageVersion) ImageRef() string {
 }
 
 type App struct {
-	ID             string
-	Name           string
-	State          string
-	Status         string
-	Deployed       bool
-	Hostname       string
-	AppURL         string
-	Version        int
+	ID        string
+	Name      string
+	State     string
+	Status    string
+	Deployed  bool
+	Hostname  string
+	AppURL    string
+	Version   int
+	NetworkID int
+
 	Release        *Release
 	Organization   Organization
 	Secrets        []Secret
