@@ -250,6 +250,8 @@ func runAttachCluster(ctx context.Context, leaderIP string, params AttachParams)
 
 	pgclient := flypg.NewFromInstance(leaderIP, dialer)
 
+	fmt.Fprintln(io.Out, "Checking for existing attachments")
+
 	secrets, err := client.GetAppSecrets(ctx, input.AppID)
 	if err != nil {
 		return err
@@ -286,6 +288,8 @@ func runAttachCluster(ctx context.Context, leaderIP string, params AttachParams)
 		return fmt.Errorf("database user %q already exists. Please specify a new database user via --database-user", *input.DatabaseUser)
 	}
 
+	fmt.Fprintln(io.Out, "Registering attachment")
+
 	// Create attachment
 	_, err = client.AttachPostgresCluster(ctx, input)
 	if err != nil {
@@ -294,6 +298,8 @@ func runAttachCluster(ctx context.Context, leaderIP string, params AttachParams)
 
 	// Create database if it doesn't already exist
 	if !dbExists {
+		fmt.Fprintln(io.Out, "Creating database")
+
 		err := pgclient.CreateDatabase(ctx, *input.DatabaseName)
 		if err != nil {
 			if flypg.ErrorStatus(err) >= 500 {
@@ -309,6 +315,8 @@ func runAttachCluster(ctx context.Context, leaderIP string, params AttachParams)
 		return err
 	}
 
+	fmt.Fprintln(io.Out, "Creating user")
+
 	err = pgclient.CreateUser(ctx, *input.DatabaseUser, pwd, true)
 	if err != nil {
 		return fmt.Errorf("failed executing create-user: %w", err)
